import { OperationFields } from './typeOptions';
import { UserFields, UserReturnType } from './user';
import { SelectUserReturnType } from './user';
export declare type SelectAssetReturnType<S extends AssetFields> = {
    [P in keyof S]: P extends 'uploaded_by' ? SelectUserReturnType<NonNullable<S['uploaded_by']>['fields']> : P extends keyof AssetReturnType ? AssetReturnType[P] : AssetReturnType;
};
export interface AssetFields extends OperationFields {
    /**
     * The file's creation date.
     */
    created_at?: boolean;
    /**
     * The file's extension.
     */
    file_extension?: boolean;
    /**
     * The file's size in bytes.
     */
    file_size?: boolean;
    /**
     * The file's unique identifier.
     */
    id?: boolean;
    /**
     * The file's name.
     */
    name?: boolean;
    /**
     * original geometry of the asset.
     */
    original_geometry?: boolean;
    /**
     * public url to the asset, valid for 1 hour.
     */
    public_url?: boolean;
    /**
     * The user who uploaded the file.
     */
    uploaded_by?: {
        fields: UserFields;
    };
    /**
     * url to view the asset.
     */
    url?: boolean;
    /**
     * url to view the asset in thumbnail mode. Only available for images.
     */
    url_thumbnail?: boolean;
}
export interface AssetReturnType {
    /**
     * The file's creation date.
     */
    created_at: string | null;
    /**
     * The file's extension.
     */
    file_extension: string;
    /**
     * The file's size in bytes.
     */
    file_size: number;
    /**
     * The file's unique identifier.
     */
    id: string;
    /**
     * The file's name.
     */
    name: string;
    /**
     * original geometry of the asset.
     */
    original_geometry: string | null;
    /**
     * public url to the asset, valid for 1 hour.
     */
    public_url: string;
    /**
     * The user who uploaded the file.
     */
    uploaded_by: UserReturnType;
    /**
     * url to view the asset.
     */
    url: string;
    /**
     * url to view the asset in thumbnail mode. Only available for images.
     */
    url_thumbnail: string | null;
}
//# sourceMappingURL=asset.d.ts.map