/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ID } from '../../types/id';
import { SelectAssetReturnType, AssetFields, AssetReturnType } from '../asset';
import { ColumnReturnType } from '../column';
import { ColumnValueFields } from '../columnValue';
import { SelectDocsReturnType, DocsFields, DocsReturnType } from '../doc';
import { OperationFields } from '../typeOptions';
import { SelectUserReturnType, UserFields, UserReturnType } from '../user';
export declare type SelectFileValueReturnType<S extends FileValueFields> = {
    [P in keyof S]: P extends keyof FileValueReturnType ? FileValueReturnType[P] : FileValueReturnType;
};
export interface FileValueFields extends ColumnValueFields {
    /**
     * The column's attached files.
     */
    files?: {
        fields: {
            __typename?: boolean;
        };
        fragments: {
            /**
             * Column values specific to asset files.
             */
            FileAssetValue: FileAssetValueFields;
            /**
             * Column values specific to Monday doc files.
             */
            FileDocValue: FileDocValueFields;
            /**
             * Column values specific to linked files.
             */
            FileLinkValue: FileLinkValueFields;
        };
    };
}
export interface FileValueReturnType extends ColumnReturnType {
    /**
     * The column's attached files.
     */
    files?: {
        __typename: string | null;
    }[];
}
export declare type SelectFileAssetValueReturnType<S extends FileAssetValueFields> = {
    [P in keyof S]: P extends 'asset' ? SelectAssetReturnType<NonNullable<S['asset']>['fields']> : P extends 'creator' ? SelectUserReturnType<NonNullable<S['creator']>['fields']> : P extends keyof FileAssetValueReturnType ? FileAssetValueReturnType[P] : FileAssetValueReturnType;
};
export interface FileAssetValueFields extends OperationFields {
    /**
     * The asset associated with the file.
     */
    asset?: {
        fields: AssetFields;
    };
    /**
     * The asset's id.
     */
    asset_id?: boolean;
    /**
     * The file's creation date.
     */
    created_at?: boolean;
    /**
     * The user who created the file.
     */
    creator?: {
        fields: UserFields;
    };
    /**
     * The ID of user who created the file.
     */
    creator_id?: boolean;
    /**
     * Whether the file is an image.
     */
    is_image?: boolean;
    /**
     * The file's name.
     */
    name?: boolean;
}
export interface FileAssetValueReturnType {
    /**
     * The asset associated with the file.
     */
    asset?: AssetReturnType | null;
    /**
     * The asset's id.
     */
    asset_id?: ID | null;
    /**
     * The file's creation date.
     */
    created_at?: string | null;
    /**
     * The user who created the file.
     */
    creator?: UserReturnType | null;
    /**
     * The ID of user who created the file.
     */
    creator_id?: number | null;
    /**
     * Whether the file is an image.
     */
    is_image?: boolean | null;
    /**
     * The file's name.
     */
    name?: string | null;
}
export declare type SelectFileDocValueReturnType<S extends FileDocValueFields> = {
    [P in keyof S]: P extends 'creator' ? SelectUserReturnType<NonNullable<S['creator']>['fields']> : P extends 'doc' ? SelectDocsReturnType<NonNullable<S['doc']>['fields']> : P extends keyof FileDocValueReturnType ? FileDocValueReturnType[P] : FileDocValueReturnType;
};
export interface FileDocValueFields extends OperationFields {
    /**
     * The file's creation date.
     */
    created_at?: boolean;
    /**
     * The user who created the file.
     */
    creator?: {
        fields: UserFields;
    };
    /**
     * The ID of user who created the file.
     */
    creator_id?: boolean;
    /**
     * The doc associated with the file.
     */
    doc?: {
        fields: DocsFields;
    };
    /**
     * The file's unique identifier.
     */
    file_id?: boolean;
    /**
     * The associated board or object's unique identifier.
     */
    object_id?: boolean;
    /**
     * The file's url.
     */
    url?: boolean;
}
export interface FileDocValueReturnType {
    /**
     * The file's creation date.
     */
    created_at?: string | null;
    /**
     * The user who created the file.
     */
    creator?: UserReturnType | null;
    /**
     * The ID of user who created the file.
     */
    creator_id?: number | null;
    /**
     * The doc associated with the file.
     */
    doc?: DocsReturnType | null;
    /**
     * The file's unique identifier.
     */
    file_id?: ID | null;
    /**
     * The associated board or object's unique identifier.
     */
    object_id?: ID | null;
    /**
     * The file's url.
     */
    url?: string | null;
}
export declare type SelectFileLinkValueReturnType<S extends FileLinkValueFields> = {
    [P in keyof S]: P extends 'creator' ? SelectUserReturnType<NonNullable<S['creator']>['fields']> : P extends keyof FileLinkValueReturnType ? FileLinkValueReturnType[P] : FileLinkValueReturnType;
};
export interface FileLinkValueFields extends OperationFields {
    /**
     * The file's creation date.
     */
    created_at?: boolean;
    /**
     * The user who created the file.
     */
    creator?: {
        fields: UserFields;
    };
    /**
     * The ID of user who created the file.
     */
    creator_id?: boolean;
    /**
     * The file's id.
     */
    file_id?: boolean;
    /**
     * The file's kind.
     */
    kind?: boolean;
    /**
     * The file's name.
     */
    name?: boolean;
    /**
     * The file's url.
     */
    url?: boolean;
}
export interface FileLinkValueReturnType {
    /**
     * The file's creation date.
     */
    created_at?: string | null;
    /**
     * The user who created the file.
     */
    creator?: UserReturnType | null;
    /**
     * The ID of user who created the file.
     */
    creator_id?: number | null;
    /**
     * The file's id.
     */
    file_id?: ID | null;
    /**
     * The file's kind.
     */
    kind?: 'google_drive' | 'dropbox' | 'box' | 'onedrive' | 'link' | null;
    /**
     * The file's name.
     */
    name?: string | null;
    /**
     * The file's url.
     */
    url?: string | null;
}
//# sourceMappingURL=fileValue.d.ts.map