/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { BoardFields, BoardReturnType, SelectBoardReturnType } from '../board';
import { ColumnReturnType } from '../column';
import { ColumnValueFields } from '../columnValue';
import { ItemFields, ItemReturnType, SelectItemReturnType } from '../item';
import { OperationFields } from '../typeOptions';
export declare type SelectMirrorValueReturnType<S extends MirrorValueFields> = {
    [P in keyof S]: P extends 'mirrored_items' ? Array<SelectMirroredItemReturnType<NonNullable<S['mirrored_items']>['fields']>> : P extends keyof MirrorValueReturnType ? MirrorValueReturnType[P] : MirrorValueReturnType;
};
export interface MirrorValueFields extends ColumnValueFields {
    /**
     * 	The content of the mirrored column, in text format.
     */
    display_value?: boolean;
    /**
     * The mirrored items.
     */
    mirrored_items?: {
        fields: MirroredItemFields;
    };
}
export interface MirrorValueReturnType extends ColumnReturnType {
    /**
     * 	The content of the mirrored column, in text format.
     */
    display_value?: string | null;
    /**
     * The mirrored items.
     */
    mirrored_items?: MirrorValueReturnType[] | null;
}
export declare type SelectMirroredItemReturnType<S extends MirroredItemFields> = {
    [P in keyof S]: P extends 'linked_board' ? SelectBoardReturnType<NonNullable<S['linked_board']>['fields']> : P extends 'linked_item' ? SelectItemReturnType<NonNullable<S['linked_item']>['fields']> : P extends keyof MirroredItemReturnType ? MirroredItemReturnType[P] : MirroredItemReturnType;
};
export interface MirroredItemFields extends OperationFields {
    /**
     * The linked board.
     */
    linked_board?: {
        fields: BoardFields;
    };
    /**
     * The linked board's unique identifier.
     */
    linked_board_id?: boolean;
    /**
     * The linked item.
     */
    linked_item?: {
        fields: ItemFields;
    };
}
export interface MirroredItemReturnType {
    /**
     * The linked board.
     */
    linked_board?: BoardReturnType | null;
    /**
     * The linked board's unique identifier.
     */
    linked_board_id?: number | null;
    /**
     * The linked item.
     */
    linked_item?: ItemReturnType | null;
}
//# sourceMappingURL=mirrorValue.d.ts.map