/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { OperationFields } from './typeOptions';
export declare type ComplexityOption = {
    complexity?: ComplexityFields;
};
export declare type SelectComplexityReturnType<S extends ComplexityFields | undefined> = {
    [P in keyof S]: P extends keyof ComplexityReturnType ? ComplexityReturnType[P] : ComplexityReturnType;
};
export interface ComplexityFields extends OperationFields {
    /**
     * The remainder of complexity after the query's execution.
     */
    after?: boolean;
    /**
     * The remainder of complexity before the query's execution.
     */
    before?: boolean;
    /**
     * The specific query's complexity.
     */
    query?: boolean;
    /**
     * How long in seconds before the complexity budget is reset
     */
    reset_in_x_seconds?: boolean;
}
export interface ComplexityReturnType {
    /**
     * The remainder of complexity after the query's execution.
     */
    after?: number;
    /**
     * The remainder of complexity before the query's execution.
     */
    before?: number;
    /**
     * The specific query's complexity.
     */
    query?: number;
    /**
     * How long in seconds before the complexity budget is reset
     */
    reset_in_x_seconds?: number;
}
//# sourceMappingURL=complexity.d.ts.map