/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ID } from '../types/id';
import { OperationFields } from './typeOptions';
import { SelectUserReturnType, UserFields, UserReturnType } from './user';
export declare type SelectDocBlockReturnType<S extends DocBlockFields> = {
    [P in keyof S]: P extends 'created_by' ? Array<SelectUserReturnType<NonNullable<S['created_by']>['fields']>> : P extends keyof DocBlockReturnType ? DocBlockReturnType[P] : DocBlockReturnType;
};
export interface GetDocBlockFields extends OperationFields {
    blocks?: {
        args?: {
            /**
             * The number of docs to get. The default is 25.
             */
            limit?: number;
            /**
             * The page number to return. Starts at 1.
             */
            page?: number;
        };
        fields: DocBlockFields;
    };
}
export interface DocBlockFields extends OperationFields {
    /**
     * The block's creation date. Returned in YYYY-MM-DD format.
     */
    created_at?: boolean;
    /**
     * The block's creator.
     */
    created_by?: {
        fields: UserFields;
    };
    /**
     * The document's unique identifier.
     */
    doc_id?: boolean;
    /**
     * The block's unique identifier.
     */
    id?: boolean;
    /**
     * The parent block's unique identifier. First-level blocks will return null.
     */
    parent_block_id?: boolean;
    /**
     * The block's position in the document.
     */
    position?: boolean;
    /**
     * The block's content type.
     */
    type?: boolean;
    /**
     * The date the block was last updated. Returned in YYYY-MM-DD format.
     */
    updated_at?: boolean;
    /**
     * The block's content.
     */
    content?: boolean;
}
export interface DocBlockReturnType {
    /**
     * The block's creation date. Returned in YYYY-MM-DD format.
     */
    created_at: string | null;
    /**
     * The block's creator.
     */
    created_by: UserReturnType | null;
    /**
     * The document's unique identifier.
     */
    doc_id: ID | null;
    /**
     * The block's unique identifier.
     */
    id: string | null;
    /**
     * The parent block's unique identifier. First-level blocks will return null.
     */
    parent_block_id: string | null;
    /**
     * The block's position in the document.
     */
    position: number | null;
    /**
     * The block's content type.
     */
    type: string | null;
    /**
     * The date the block was last updated. Returned in YYYY-MM-DD format.
     */
    updated_at: string | null;
    /**
     * The block's content.
     */
    content: JSON | null;
}
//# sourceMappingURL=docBlock.d.ts.map