/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { BoardFields, BoardReturnType, SelectBoardReturnType } from './board';
import { OperationFields } from './typeOptions';
import { SelectWorkspaceReturnType, WorkspaceFields, WorkspaceReturnType } from './workspace';
export declare type SelectFolderReturnType<S extends FolderFields> = {
    [P in keyof S]: P extends 'children' ? Array<SelectBoardReturnType<NonNullable<S['children']>['fields']>> : P extends 'sub_folders' ? Array<SelectFolderReturnType<NonNullable<S['sub_folders']>['fields']>> : P extends 'workspace' ? Array<SelectWorkspaceReturnType<NonNullable<S['workspace']>['fields']>> : P extends keyof FolderReturnType ? FolderReturnType[P] : FolderReturnType;
};
export interface FolderFields extends OperationFields {
    /**
     * The folder's contents, excluding dashboards and subfolders.
     */
    children?: {
        fields: BoardFields;
    };
    /**
     * The folder's color.
     */
    color?: boolean;
    /**
     * The folder's creation date.
     */
    created_at?: boolean;
    /**
     * The folder's unique identifier.
     */
    id?: boolean;
    /**
     * The folder's name.
     */
    name?: boolean;
    /**
     * The unique identifier of the folder's owner.
     */
    owner_id?: boolean;
    /**
     * The folders inside of the parent folder.
     */
    sub_folders?: {
        fields: FolderFields;
    };
    /**
     * The workspace that contains the folder.
     */
    workspace?: {
        fields: WorkspaceFields;
    };
}
export interface FolderReturnType {
    /**
     * The folder's contents, excluding dashboards and subfolders.
     */
    children: BoardReturnType | null;
    /**
     * The folder's color.
     */
    color: FolderColor | null;
    /**
     * The folder's creation date.
     */
    created_at: string | null;
    /**
     * The folder's unique identifier.
     */
    id: number | null;
    /**
     * The folder's name.
     */
    name: string | null;
    /**
     * The unique identifier of the folder's owner.
     */
    owner_id: number | null;
    /**
     * The folders inside of the parent folder.
     */
    sub_folders: FolderReturnType | null;
    /**
     * The workspace that contains the folder.
     */
    workspace: WorkspaceReturnType | null;
}
export declare type FolderColor = 'DONE_GREEN' | 'BRIGHT_GREEN' | 'WORKING_ORANGE' | 'DARK_ORANGE' | 'SUNSET' | 'STUCK_RED' | 'DARK_RED' | 'SOFIA_PINK' | 'LIPSTICK' | 'PURPLE' | 'DARK_PURPLE' | 'INDIGO' | 'BRIGHT_BLUE' | 'AQUAMARINE' | 'CHILI_BLUE';
//# sourceMappingURL=folder.d.ts.map