/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ItemsQuery } from '../types/itemsPage';
import { ItemFields, ItemReturnType, SelectItemReturnType } from './item';
import { OperationFields } from './typeOptions';
export declare type SelectItemsPageReturnType<S extends ItemsPageFields> = {
    [P in keyof S]: P extends 'items' ? Array<SelectItemReturnType<NonNullable<S['items']>['fields']>> : P extends keyof ItemsPageReturnType ? ItemsPageReturnType[P] : ItemsPageReturnType;
};
export interface ItemsPageFields extends OperationFields {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: boolean;
    /**
     * The cursor's corresponding item.
     */
    items?: {
        fields: ItemFields;
    };
}
export declare type ItemsPageArgs = ItemsPageFieldsArgsWithQuery | ItemsPageFieldsArgsWithCursor;
interface ItemsPageFieldsArgsWithQuery {
    /**
     * A set of parameters to filter, sort, and control the scope of the boards query. Use this to customize the results based on specific criteria.
     * Please note that you can't use query_params and cursor in the same request. We recommend using query_params for the initial request and cursor
     * for paginated requests.
     */
    query_params?: ItemsQuery;
    /**
     * The number of items to return. The default is 25, but the maximum is 500.
     */
    limit?: number;
    cursor?: never;
}
interface ItemsPageFieldsArgsWithCursor {
    /**
     * An opaque token representing the position in a set of results to fetch items from. Use this to paginate through large result sets.
     * Please note that you can't use query_params and cursor in the same request. We recommend using query_params for the initial request
     * and cursor for paginated requests.
     */
    cursor: string;
    /**
     * The number of items to return. The default is 25, but the maximum is 500.
     */
    limit?: number;
    query_params?: never;
}
export interface ItemsPageReturnType {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: string;
    /**
     * The cursor's corresponding item.
     */
    items?: ItemReturnType[];
}
export declare type SelectNextItemsPageReturnType<S extends NextItemsPageFields> = {
    [P in keyof S]: P extends 'items' ? Array<SelectItemReturnType<NonNullable<S['items']>['fields']>> : P extends keyof NextItemsPageReturnType ? NextItemsPageReturnType[P] : NextItemsPageReturnType;
};
export interface NextItemsPageFields extends OperationFields {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: boolean;
    /**
     * The cursor's corresponding item.
     */
    items?: {
        fields: ItemFields;
    };
}
export interface NextItemsPageReturnType {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: string;
    /**
     * The cursor's corresponding item.
     */
    items: ItemReturnType[];
}
export declare type SelectItemsPageByColumnValuesReturnType<S extends ItemsPageByColumnValuesFields> = {
    [P in keyof S]: P extends 'items' ? Array<SelectItemReturnType<NonNullable<S['items']>['fields']>> : P extends keyof ItemsPageByColumnValuesReturnType ? ItemsPageByColumnValuesReturnType[P] : ItemsPageByColumnValuesReturnType;
};
export interface ItemsPageByColumnValuesFields extends OperationFields {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: boolean;
    /**
     * The items associated with the cursor.
     */
    items?: {
        fields: ItemFields;
    };
}
export interface ItemsPageByColumnValuesReturnType {
    /**
     * An opaque cursor that represents the position in the list after the last returned item.
     * Use this cursor for pagination to fetch the next set of items. If the cursor is null, there are no more items to fetch.
     */
    cursor?: string;
    /**
     * The items associated with the cursor.
     */
    items: ItemReturnType[];
}
export {};
//# sourceMappingURL=itemsPage.d.ts.map