import { AssetReturnType, AssetFields } from './asset';
import { ReplyFields, ReplyReturnType } from './reply';
import { OperationFields } from './typeOptions';
import { UserFields, UserReturnType, SelectUserReturnType } from './user';
import { SelectAssetReturnType } from './asset';
import { SelectReplyReturnType } from './reply';
export declare type SelectUpdateReturnType<S extends UpdateFields> = {
    [P in keyof S]: P extends 'assets' ? Array<SelectAssetReturnType<NonNullable<S['assets']>['fields']>> : P extends 'creator' ? SelectUserReturnType<NonNullable<S['creator']>['fields']> : P extends 'replies' ? Array<SelectReplyReturnType<NonNullable<S['replies']>['fields']>> : P extends keyof UpdateReturnType ? UpdateReturnType[P] : UpdateReturnType;
};
export interface UpdateFields extends OperationFields {
    /**
     * The update's assets/files.
     */
    assets?: {
        fields: AssetFields;
    };
    /**
     * The update's html formatted body.
     */
    body?: boolean;
    /**
     * The update's creation date.
     */
    created_at?: boolean;
    /**
     * The update's creator.
     */
    creator?: {
        fields: UserFields;
    };
    /**
     * The unique identifier of the update creator.
     */
    creator_id?: boolean;
    /**
     * The update's unique identifier.
     */
    id?: boolean;
    /**
     * The update's item ID.
     */
    item_id?: boolean;
    /**
     * The update's replies.
     */
    replies?: {
        fields: ReplyFields;
    };
    /**
     * The update's text body.
     */
    text_body?: boolean;
    /**
     * The update's last edit date.
     */
    updated_at?: boolean;
}
export interface UpdateReturnType {
    /**
     * The update's assets/files.
     */
    assets: AssetReturnType[] | null;
    /**
     * The update's html formatted body.
     */
    body: string;
    /**
     * The update's creation date.
     */
    created_at: string | null;
    /**
     * The update's creator.
     */
    creator: UserReturnType | null;
    /**
     * The unique identifier of the update creator.
     */
    creator_id: string | null;
    /**
     * The update's unique identifier.
     */
    id: string;
    /**
     * The update's item ID.
     */
    item_id: string | null;
    /**
     * The update's replies.
     */
    replies: ReplyReturnType[] | null;
    /**
     * The update's text body.
     */
    text_body: string | null;
    /**
     * The update's last edit date.
     */
    updated_at: string | null;
}
//# sourceMappingURL=update.d.ts.map