/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { ColumnFields, ColumnProperty, ColumnReturnType, ColumnType, SelectColumnReturnType } from '../definitions/column';
import { ErrorStrategyOption } from '../errorStrategy';
import { ItemFields, ItemReturnType, SelectItemReturnType } from '../definitions/item';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface CreateColumnRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The new column's title.
         */
        title: string;
        /**
         * The new column's description.
         */
        description?: string;
        /**
         * The type of column to create.
         */
        column_type?: ColumnType;
        /**
         * The new column's defaults.
         */
        defaults?: Record<string | number, any>;
        /**
         * The column's user-specified unique identifier.
         */
        id?: string;
        /**
         * The unique identifier of the column after which the new column will be created.
         */
        after_column_id: ID;
    };
    fields: ColumnFields;
    complexity?: ComplexityFields;
}
export interface CreateColumnResponseOK<S extends CreateColumnRequest = CreateColumnRequest> {
    data: {
        create_column: SelectColumnReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateColumnFullResponseOK {
    data: {
        create_column: ColumnReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnValueRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The item's unique identifier.
         */
        item_id: ID;
        /**
         * The column's unique identifier.
         */
        column_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The new value of the column.
         */
        value: Record<string | number, any> | string;
        /**
         * Create Status/Dropdown labels if they're missing.
         */
        create_labels_if_missing?: boolean;
    };
    fields: ItemFields;
    complexity?: ComplexityFields;
}
export interface ChangeColumnValueResponseOK<S extends ChangeColumnValueRequest = ChangeColumnValueRequest> {
    data: {
        change_column_value: SelectItemReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnValueFullResponseOK {
    data: {
        change_column_value: ItemReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeSimpleColumnValueRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The item's unique identifier.
         */
        item_id: ID;
        /**
         * The column's unique identifier.
         */
        column_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The new simple value of the column.
         */
        value: string;
        /**
         * Create Status/Dropdown labels if they're missing.
         */
        create_labels_if_missing?: boolean;
    };
    fields: ItemFields;
    complexity?: ComplexityFields;
}
export interface ChangeSimpleColumnValueResponseOK<S extends ChangeSimpleColumnValueRequest = ChangeSimpleColumnValueRequest> {
    data: {
        change_simple_column_value: SelectItemReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeSimpleColumnValueFullResponseOK {
    data: {
        change_simple_column_value: ItemReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeMultipleColumnValuesRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The item's unique identifier.
         */
        item_id: ID;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The column values updates.
         */
        column_values: Record<string, any>;
        /**
         * Create Status/Dropdown labels if they're missing.
         */
        create_labels_if_missing?: boolean;
    };
    fields: ItemFields;
    complexity?: ComplexityFields;
}
export interface ChangeMultipleColumnValuesResponseOK<S extends ChangeMultipleColumnValuesRequest = ChangeMultipleColumnValuesRequest> {
    data: {
        change_multiple_column_values: SelectItemReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeMultipleColumnValuesFullResponseOK {
    data: {
        change_multiple_column_values: ItemReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnTitleRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The column's unique identifier.
         */
        column_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The new title of the column.
         */
        title: string;
    };
    fields: ColumnFields;
    complexity?: ComplexityFields;
}
export interface ChangeColumnTitleResponseOK<S extends ChangeColumnTitleRequest = ChangeColumnTitleRequest> {
    data: {
        change_column_title: SelectColumnReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnTitleFullResponseOK {
    data: {
        change_column_title: ColumnReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnMetadataRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The column's unique identifier.
         */
        column_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The property name of the column to be changed (title / description).
         */
        column_property: ColumnProperty;
        /**
         * The new description of the column.
         */
        value: string;
    };
    fields: ColumnFields;
    complexity?: ComplexityFields;
}
export interface ChangeColumnMetadataResponseOK<S extends ChangeColumnMetadataRequest = ChangeColumnMetadataRequest> {
    data: {
        change_column_metadata: SelectColumnReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ChangeColumnMetadataFullResponseOK {
    data: {
        change_column_metadata: ColumnReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteColumnRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The column's unique identifier.
         */
        column_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: ID;
    };
    fields: ColumnFields;
    complexity?: ComplexityFields;
}
export interface DeleteColumnResponseOK<S extends DeleteColumnRequest = DeleteColumnRequest> {
    data: {
        delete_column: SelectColumnReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteColumnFullResponseOK {
    data: {
        delete_column: ColumnReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=column.d.ts.map