/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { SelectFolderReturnType, FolderReturnType, FolderFields, FolderColor } from '../definitions/folder';
import { ErrorStrategyOption } from '../errorStrategy';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface GetFoldersRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The specific folders to return.
         */
        ids?: ID[];
        /**
         * The unique identifiers of the specific workspaces to return. You can query [null] to return folders in the Main Workspace.
         */
        workspace_ids?: ID[];
        /**
         * The number of folders to get. The default is 25 and the maximum is 100.
         */
        limit?: number;
        /**
         * The page number to return. Starts at 1.
         */
        page?: number;
    };
    fields: FolderFields;
    complexity?: ComplexityFields;
}
export interface GetFoldersResponseOK<S extends GetFoldersRequest = GetFoldersRequest> {
    data: {
        folders: Array<SelectFolderReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetFoldersFullResponseOK {
    data: {
        folders: FolderReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateFolderRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The folder's color.
         */
        color?: FolderColor;
        /**
         * The folder's name.
         */
        name: string;
        /**
         * The ID of the folder you want to nest the new one under.
         */
        parent_folder_id?: ID;
        /**
         * The unique identifier of the workspace to create the new folder in.
         */
        workspace_id?: ID;
    };
    fields: FolderFields;
    complexity?: ComplexityFields;
}
export interface CreateFolderResponseOK<S extends CreateFolderRequest = CreateFolderRequest> {
    data: {
        create_folder: Array<SelectFolderReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateFolderFullResponseOK {
    data: {
        create_folder: FolderReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateFolderRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The folder's color.
         */
        color?: FolderColor;
        /**
         * The folder's unique identifier.
         */
        folder_id: ID;
        /**
         * The folder's name.
         */
        name?: string;
        /**
         * The ID of the folder you want to nest the new one under.
         */
        parent_folder_id?: ID;
    };
    fields: FolderFields;
    complexity?: ComplexityFields;
}
export interface UpdateFolderResponseOK<S extends UpdateFolderRequest = UpdateFolderRequest> {
    data: {
        update_folder: Array<SelectFolderReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateFolderFullResponseOK {
    data: {
        update_folder: FolderReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteFolderRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The folder's unique identifier.
         */
        folder_id: ID;
    };
    fields: FolderFields;
    complexity?: ComplexityFields;
}
export interface DeleteFolderResponseOK<S extends DeleteFolderRequest = DeleteFolderRequest> {
    data: {
        delete_folder: Array<SelectFolderReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteFolderFullResponseOK {
    data: {
        delete_folder: FolderReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=folder.d.ts.map