import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { NotificationFields, NotificationReturnType, NotificationTargetType, SelectNotificationReturnType } from '../definitions/notification';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface CreateNotificationRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The target's type: project or post.
         * - Project: sends a notification referring to a specific item or board
         * - Post : sends a notification referring to a specific item's update or reply
         */
        target_type: NotificationTargetType;
        /**
         * The target's unique identifier. The value depends on the target_type:
         * - Project: the relevant item or board ID
         * - Post : the relevant update or reply ID
         */
        target_id: ID;
        /**
         * The notification's text.
         */
        text: string;
        /**
         * The user's unique identifier.
         */
        user_id: ID;
    };
    fields: NotificationFields;
    complexity?: ComplexityFields;
}
export interface CreateNotificationResponseOK<S extends CreateNotificationRequest = CreateNotificationRequest> {
    data: {
        create_notification: SelectNotificationReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateNotificationFullResponseOK {
    data: {
        create_notification: NotificationReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=notification.d.ts.map