import { HeadersOption } from '@managed-api/commons-core';
import { ErrorStrategyOption } from '../errorStrategy';
import { ChangeTeamMembershipResultFields, ChangeTeamMembershipResultReturnType, SelectChangeTeamMembershipResultReturnType, SelectTeamReturnType, TeamFields, TeamReturnType } from '../definitions/team';
import { WorkspaceSubscriberKind } from '../definitions/workspace';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface GetTeamsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The unique identifiers of the specific teams to return.
         */
        ids?: ID[];
    };
    fields: TeamFields;
    complexity?: ComplexityFields;
}
export interface AddTeamsToBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: ID;
        /**
         * The unique identifiers of the teams to add to the board.
         */
        team_ids: ID[];
    };
    fields: TeamFields;
    complexity?: ComplexityFields;
}
export interface AddTeamsToWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifiers of the teams to add to the workspace.
         */
        team_ids: ID[];
        /**
         * The workspace's unique identifier.
         */
        workspace_id: ID;
        /**
         * The subscriber's role: owner or subscriber.
         */
        kind?: WorkspaceSubscriberKind | null;
    };
    fields: TeamFields;
    complexity?: ComplexityFields;
}
export interface DeleteTeamsFromWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifiers of the teams to delete from the workspace.
         */
        team_ids: ID[];
        /**
         * The workspace's unique identifier.
         */
        workspace_id: ID;
    };
    fields: TeamFields;
    complexity?: ComplexityFields;
}
export interface DeleteTeamsFromBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifiers of the teams to delete from the board.
         */
        team_ids: ID[];
        /**
         * The board's unique identifier.
         */
        board_id: ID;
    };
    fields: TeamFields;
    complexity?: ComplexityFields;
}
export interface AddUsersToTeamRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifier of the team to add users to.
         */
        team_id: ID;
        /**
         * The unique identifiers of the users to add to the team.
         */
        user_ids: ID[];
    };
    fields: ChangeTeamMembershipResultFields;
    complexity?: ComplexityFields;
}
export interface RemoveUsersFromTeamRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifier of the team to remove users from.
         */
        team_id: ID;
        /**
         * The unique identifiers of the users to remove from the team.
         */
        user_ids: ID[];
    };
    fields: ChangeTeamMembershipResultFields;
    complexity?: ComplexityFields;
}
export interface AddTeamsToBoardResponseOK<S extends AddTeamsToBoardRequest = AddTeamsToBoardRequest> {
    data: {
        teams: Array<SelectTeamReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddTeamsToBoardFullResponseOK {
    data: {
        add_teams_to_board: TeamReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetTeamsResponseOK<S extends GetTeamsRequest = GetTeamsRequest> {
    data: {
        teams: Array<SelectTeamReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetTeamsFullResponseOK {
    data: {
        teams: TeamReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddTeamsToWorkspaceResponseOK<S extends AddTeamsToWorkspaceRequest = AddTeamsToWorkspaceRequest> {
    data: {
        add_teams_to_workspace: Array<SelectTeamReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddTeamsToWorkspaceFullResponseOK {
    data: {
        add_teams_to_workspace: TeamReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteTeamsFromWorkspaceResponseOK<S extends DeleteTeamsFromWorkspaceRequest = DeleteTeamsFromWorkspaceRequest> {
    data: {
        delete_teams_from_workspace: Array<SelectTeamReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteTeamsFromWorkspaceFullResponseOK {
    data: {
        delete_teams_from_workspace: TeamReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteTeamsFromBoardResponseOK<S extends DeleteTeamsFromBoardRequest = DeleteTeamsFromBoardRequest> {
    data: {
        delete_teams_from_board: Array<SelectTeamReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteTeamsFromBoardFullResponseOK {
    data: {
        delete_teams_from_board: TeamReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToTeamResponseOK<S extends AddUsersToTeamRequest = AddUsersToTeamRequest> {
    data: {
        add_users_to_team: SelectChangeTeamMembershipResultReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface AddUsersToTeamFullResponseOK {
    data: {
        add_users_to_team: ChangeTeamMembershipResultReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface RemoveUsersFromTeamResponseOK<S extends RemoveUsersFromTeamRequest = RemoveUsersFromTeamRequest> {
    data: {
        remove_users_from_team: SelectChangeTeamMembershipResultReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface RemoveUsersFromTeamFullResponseOK {
    data: {
        remove_users_from_team: ChangeTeamMembershipResultReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=team.d.ts.map