/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { SelectUpdateReturnType, UpdateFields, UpdateReturnType } from '../definitions/update';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface GetUpdatesRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The specific ID(s) to return updates for.
         */
        ids?: ID[];
        /**
         * The number of updates to return. The default is 25.
         */
        limit?: number;
        /**
         * The page number to get. Starts at 1.
         */
        page?: number;
    };
    fields: UpdateFields;
    complexity?: ComplexityFields;
}
export interface GetUpdatesResponseOK<S extends GetUpdatesRequest = GetUpdatesRequest> {
    data: {
        updates: Array<SelectUpdateReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetUpdatesFullResponseOK {
    data: {
        updates: UpdateReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateUpdateRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The update's text.
         */
        body: string;
        /**
         * The item's unique identifier.
         */
        item_id?: ID;
        /**
         * The parent update's unique identifier. This can be used to create a reply to an update.
         */
        parent_id?: ID;
    };
    fields: UpdateFields;
    complexity?: ComplexityFields;
}
export interface CreateUpdateResponseOK<S extends CreateUpdateRequest = CreateUpdateRequest> {
    data: {
        create_update: SelectUpdateReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateUpdateFullResponseOK {
    data: {
        create_update: UpdateReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteUpdateRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The update's unique identifier.
         */
        id: ID;
    };
    fields: UpdateFields;
    complexity?: ComplexityFields;
}
export interface DeleteUpdateResponseOK<S extends DeleteUpdateRequest = DeleteUpdateRequest> {
    data: {
        delete_update: SelectUpdateReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteUpdateFullResponseOK {
    data: {
        delete_update: UpdateReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface LikeUpdateRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The update's unique identifier.
         */
        update_id: ID;
    };
    fields: UpdateFields;
    complexity?: ComplexityFields;
}
export interface LikeUpdateResponseOK<S extends LikeUpdateRequest = LikeUpdateRequest> {
    data: {
        like_update: SelectUpdateReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface LikeUpdateFullResponseOK {
    data: {
        like_update: UpdateReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=update.d.ts.map