import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { SelectWebhookReturnType, WebhookEventType, WebhookFields, WebhookReturnType } from '../definitions/webhook';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface GetWebhooksRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * 	Returns only the webhooks created by the app initiating the request.
         */
        app_webhooks_only?: boolean;
        /**
         * The unique identifier of the board that your webhook subscribes to.
         */
        board_id: ID;
    };
    fields: WebhookFields;
    complexity?: ComplexityFields;
}
export interface GetWebhooksResponseOK<S extends GetWebhooksRequest = GetWebhooksRequest> {
    data: {
        webhooks: Array<SelectWebhookReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetWebhooksFullResponseOK {
    data: {
        webhooks: WebhookReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateWebhookRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier. If creating a webhook for subitem events, send the main/parent board ID.
         */
        board_id: ID;
        /**
         * The webhook configuration.
         */
        config?: Record<string, any>;
        /**
         * The event to listen to
         */
        event: WebhookEventType;
        url: string;
    };
    fields: WebhookFields;
    complexity?: ComplexityFields;
}
export interface CreateWebhookResponseOK<S extends CreateWebhookRequest = CreateWebhookRequest> {
    data: {
        create_webhook: Array<SelectWebhookReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateWebhooksFullResponseOK {
    data: {
        create_webhook: WebhookReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteWebhookRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The webhook's unique identifier.
         */
        id: ID;
    };
    fields: WebhookFields;
    complexity?: ComplexityFields;
}
export interface DeleteWebhookResponseOK<S extends DeleteWebhookRequest = DeleteWebhookRequest> {
    data: {
        delete_webhook: Array<SelectWebhookReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteWebhooksFullResponseOK {
    data: {
        create_webhook: WebhookReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=webhook.d.ts.map