/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { SelectWorkspaceReturnType, State, WorkspaceFields, WorkspaceKind, WorkspaceReturnType, WorkspacesOrderBy } from '../definitions/workspace';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
import { ID } from './id';
export interface GetWorkspacesRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * A list of items unique identifiers.
         */
        ids?: ID[];
        /**
         * The kind of workspaces to return: open or closed.
         */
        kind?: WorkspaceKind | null;
        /**
         * Number of items to get, the default is 25.
         */
        limit?: number;
        /**
         * The order in which to retrieve your workspaces. For now, you can only order by created_at.
         */
        order_by?: WorkspacesOrderBy;
        /**
         * The page number to get. Starts at 1.
         */
        page?: number;
        /**
         * The state of workspaces you want to search by: all, active, archived, or deleted. The default is active.
         */
        state?: State | null;
    };
    fields: WorkspaceFields;
    complexity?: ComplexityFields;
}
export interface GetWorkspacesResponseOK<S extends GetWorkspacesRequest = GetWorkspacesRequest> {
    data: {
        workspaces: Array<SelectWorkspaceReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetWorkspacesFullResponseOK {
    data: {
        workspaces: WorkspaceReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The new workspace's name.
         */
        name: string;
        /**
         * The new workspace's description.
         */
        description?: string;
        /**
         * The new workspace's kind: open or closed.
         */
        kind: WorkspaceKind;
    };
    fields: WorkspaceFields;
    complexity?: ComplexityFields;
}
export interface CreateWorkspaceResponseOK<S extends CreateWorkspaceRequest = CreateWorkspaceRequest> {
    data: {
        create_workspace: SelectWorkspaceReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateWorkspaceFullResponseOK {
    data: {
        create_workspace: WorkspaceReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The unique identifier of the workspace.
         */
        id: ID;
        /**
         * The unique identifier of the workspace.
         */
        attributes: UpdateWorkspaceAttributesInput;
    };
    fields: WorkspaceFields;
    complexity?: ComplexityFields;
}
export interface UpdateWorkspaceAttributesInput {
    /**
     * The updated workspace description.
     */
    description?: string;
    /**
     * The kind of workspace to update: open or closed.
     */
    kind?: WorkspaceKind;
    /**
     * The updated workspace name.
     */
    name?: string;
}
export interface UpdateWorkspaceResponseOK<S extends UpdateWorkspaceRequest = UpdateWorkspaceRequest> {
    data: {
        update_workspace: SelectWorkspaceReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateWorkspaceFullResponseOK {
    data: {
        update_workspace: WorkspaceReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteWorkspaceRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The workspace's unique identifier.
         */
        workspace_id: ID;
    };
    fields: WorkspaceFields;
    complexity?: ComplexityFields;
}
export interface DeleteWorkspaceResponseOK<S extends DeleteWorkspaceRequest = DeleteWorkspaceRequest> {
    data: {
        delete_workspace: SelectWorkspaceReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteWorkspaceFullResponseOK {
    data: {
        delete_workspace: WorkspaceReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=workspace.d.ts.map